Clr enum

Enum representing text colors for use with the write function.

Inheritance
Available extensions

Values

red → const Clr
green → const Clr
yellow → const Clr
blue → const Clr
magenta → const Clr
cyan → const Clr
white → const Clr

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Clr>
A constant List of the values in this enum, in order of their declaration.