OptionsX extension
Extension methods for Dio Options to handle common HTTP headers configuration.
Provides convenient methods to add authentication tokens and other common headers to HTTP requests.
- on
Extension methods for Dio Options to handle common HTTP headers configuration.
Provides convenient methods to add authentication tokens and other common headers to HTTP requests.