CookieManagerSaveException class
Thrown when the cookie manager fails to save cookies.
- Implemented types
Constructors
- CookieManagerSaveException({required Response response, required Object error, required StackTrace stackTrace, required DioException? dioException})
Properties
- dioException → DioException?
-
final
- error → Object
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- response → Response
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited